@@ -28,9 +28,9 @@ class SimplePlotItem(pg.PlotItem):
                         autoExpandTextSpace=False,
                         showValues=False,
                         )
-
         # show grid
-        self.showGrid(x=True, y=True, alpha=.1)
+        # https://github.com/ZELLMECHANIK-DRESDEN/ShapeOut2/issues/75
+        # self.showGrid(x=True, y=True, alpha=.1)
         # visualization
         self.hideButtons()
 
@@ -39,7 +39,7 @@ class SimplePlotItem(pg.PlotItem):
         # bring axes to front
         # (This screws up event selection in QuickView)
         for kax in self.axes:
-            self.axes[kax]["item"].setZValue(200)
+            self.axes[kax]["item"].setZValue(900)
 
     def on_export(self, suffix):
         """Export subplots as original figures (with axes labels, etc)"""
@@ -72,20 +72,10 @@ class SimplePlotWidget(pg.PlotWidget):
     """
 
     def __init__(self, parent=None, background='w', **kargs):
-        # The following code is copied from pg.PlotWidget and instead
-        # of PlotItem we use SimplePlotItem.
-        pg.GraphicsView.__init__(self, parent, background=background)
-        self.enableMouse(False)
-        self.plotItem = SimplePlotItem(**kargs)
-        self.setCentralItem(self.plotItem)
-        # Explicitly wrap methods from plotItem
-        for m in [
-            'addItem', 'removeItem', 'autoRange', 'clear', 'setXRange',
-            'setYRange', 'setRange', 'setAspectLocked', 'setMouseEnabled',
-            'setXLink', 'setYLink', 'enableAutoRange', 'disableAutoRange',
-                'setLimits', 'register', 'unregister', 'viewRect']:
-            setattr(self, m, getattr(self.plotItem, m))
-        self.plotItem.sigRangeChanged.connect(self.viewRangeChanged)
+        plot_item = SimplePlotItem(**kargs)
+        super(SimplePlotWidget, self).__init__(parent,
+                                               background=background,
+                                               plotItem=plot_item)
 
 
 class SimpleViewBox(pg.ViewBox):
